@@ -1,9 +1,10 @@
 use crate::interactive::{
+    state::{AppState, Cursor, FocussedPane},
     widgets::{
         Entries, EntriesProps, Footer, FooterProps, GlobPane, GlobPaneProps, Header, HelpPane,
         HelpPaneProps, MarkPane, MarkPaneProps, COLOR_MARKED,
     },
-    AppState, Cursor, DisplayOptions, FocussedPane,
+    DisplayOptions,
 };
 use std::borrow::Borrow;
 use tui::backend::Backend;
@@ -19,7 +20,7 @@ use FocussedPane::*;
 pub struct MainWindowProps<'a> {
     pub current_path: String,
     pub entries_traversed: u64,
-    pub total_bytes: Option<u128>,
+    pub total_bytes: u128,
     pub start: std::time::Instant,
     pub elapsed: Option<std::time::Duration>,
     pub display: DisplayOptions,
@@ -110,6 +111,7 @@ impl MainWindow {
             border_style: entries_style,
             is_focussed: matches!(state.focussed, Main),
             sort_mode: state.sorting,
+            show_columns: &state.show_columns,
         };
         self.entries_pane
             .render(props, entries_area, terminal.current_buffer_mut());
